package org.eclipse.equinox.launcher;

import java.io.IOException;
import java.net.JarURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.jar.Manifest;

/* loaded from: org_eclipse_equinox_launcher.jar:org/eclipse/equinox/launcher/WebStartMain.class */
public class WebStartMain extends Main {
    private static final String PROP_WEBSTART_AUTOMATIC_INSTALLATION = "eclipse.webstart.automaticInstallation";
    private static final String DEFAULT_OSGI_BUNDLES = "org.eclipse.equinox.common@2:start, org.eclipse.core.runtime@start";
    private static final String PROP_OSGI_BUNDLES = "osgi.bundles";
    private static final String PROP_CHECK_CONFIG = "osgi.checkConfiguration";
    private Map allBundles = null;
    private List bundleList = null;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: org_eclipse_equinox_launcher.jar:org/eclipse/equinox/launcher/WebStartMain$BundleInfo.class */
    public class BundleInfo {
        String bsn;
        String version;
        String startData;
        String location;

        private BundleInfo() {
        }

        /* synthetic */ BundleInfo(WebStartMain webStartMain, BundleInfo bundleInfo) {
            this();
        }
    }

    public static void main(String[] args) {
        System.setSecurityManager(null);
        int result = new WebStartMain().run(args);
        if (!Boolean.getBoolean("osgi.noShutdown")) {
            System.exit(result);
        }
    }

    private void setDefaultBundles() {
        if (System.getProperty(PROP_OSGI_BUNDLES) != null) {
            return;
        }
        System.getProperties().put(PROP_OSGI_BUNDLES, DEFAULT_OSGI_BUNDLES);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.eclipse.equinox.launcher.Main
    public void basicRun(String[] args) throws Exception {
        setDefaultBundles();
        initializeBundleListStructure();
        discoverBundles();
        String fwkURL = searchFor(this.framework, null);
        this.allBundles.remove(this.framework);
        System.getProperties().put("osgi.framework", fwkURL);
        super.basicRun(args);
    }

    @Override // org.eclipse.equinox.launcher.Main
    protected void beforeFwkInvocation() {
        if (System.getProperty(PROP_CHECK_CONFIG) == null) {
            System.getProperties().put(PROP_CHECK_CONFIG, "true");
        }
        buildOSGiBundleList();
        cleanup();
    }

    private void cleanup() {
        this.allBundles = null;
        this.bundleList = null;
    }

    @Override // org.eclipse.equinox.launcher.Main
    protected String searchFor(String target, String start) {
        ArrayList matches = (ArrayList) this.allBundles.get(target);
        if (matches == null) {
            return null;
        }
        int numberOfMatches = matches.size();
        if (numberOfMatches == 1) {
            return ((BundleInfo) matches.get(0)).location;
        }
        if (numberOfMatches == 0) {
            return null;
        }
        String[] versions = new String[numberOfMatches];
        int highest = 0;
        for (int i = 0; i < versions.length; i++) {
            versions[i] = ((BundleInfo) matches.get(i)).version;
            highest = findMax(versions);
        }
        return ((BundleInfo) matches.get(highest)).location;
    }

    private BundleInfo findBundle(String target, String version, boolean removeMatch) {
        ArrayList matches = (ArrayList) this.allBundles.get(target);
        int numberOfMatches = matches.size();
        if (numberOfMatches == 1) {
            return (BundleInfo) matches.remove(0);
        }
        if (numberOfMatches == 0) {
            return null;
        }
        if (version != null) {
            Iterator iterator = matches.iterator();
            while (iterator.hasNext()) {
                BundleInfo bi = (BundleInfo) iterator.next();
                if (bi.version.equals(version)) {
                    iterator.remove();
                    return bi;
                }
            }
            return null;
        }
        String[] versions = new String[numberOfMatches];
        int highest = 0;
        for (int i = 0; i < versions.length; i++) {
            versions[i] = ((BundleInfo) matches.get(i)).version;
            highest = findMax(versions);
        }
        return (BundleInfo) matches.remove(highest);
    }

    private void discoverBundles() {
        this.allBundles = new HashMap();
        try {
            Enumeration resources = WebStartMain.class.getClassLoader().getResources("META-INF/MANIFEST.MF");
            while (resources.hasMoreElements()) {
                BundleInfo found = getBundleInfo(resources.nextElement());
                if (found != null) {
                    ArrayList matching = (ArrayList) this.allBundles.get(found.bsn);
                    if (matching == null) {
                        matching = new ArrayList(1);
                        this.allBundles.put(found.bsn, matching);
                    }
                    matching.add(found);
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private String extractInnerURL(URL url) {
        URLConnection connection = null;
        try {
            try {
                connection = url.openConnection();
            } catch (Throwable th) {
                if (connection != null) {
                    connection.getInputStream().close();
                }
                throw th;
            }
        } catch (IOException unused) {
        }
        if (connection instanceof JarURLConnection) {
            String str = "file:" + ((JarURLConnection) connection).getJarFile().getName();
            if (connection != null) {
                connection.getInputStream().close();
            }
            return str;
        }
        if (connection != null) {
            connection.getInputStream().close();
        }
        return url.toExternalForm();
    }

    private void initializeBundleListStructure() {
        String prop = System.getProperty(PROP_OSGI_BUNDLES);
        if (prop == null || prop.trim().equals("")) {
            this.bundleList = new ArrayList(0);
            return;
        }
        this.bundleList = new ArrayList(10);
        StringTokenizer tokens = new StringTokenizer(prop, ",");
        while (tokens.hasMoreTokens()) {
            String token = tokens.nextToken().trim();
            if (!token.equals("")) {
                BundleInfo toAdd = new BundleInfo(this, null);
                toAdd.bsn = token;
                int startLevelSeparator = token.lastIndexOf(64);
                if (startLevelSeparator != -1) {
                    toAdd.bsn = token.substring(0, startLevelSeparator);
                    toAdd.startData = token.substring(startLevelSeparator);
                }
                this.bundleList.add(toAdd);
            }
        }
    }

    private BundleInfo getBundleInfo(URL manifestURL) {
        try {
            Manifest mf = new Manifest(manifestURL.openStream());
            String symbolicNameString = mf.getMainAttributes().getValue("Bundle-SymbolicName");
            if (symbolicNameString == null) {
                return null;
            }
            BundleInfo result = new BundleInfo(this, null);
            String version = mf.getMainAttributes().getValue("Bundle-Version");
            result.version = version != null ? version : "0.0.0";
            result.location = extractInnerURL(manifestURL);
            int pos = symbolicNameString.lastIndexOf(59);
            if (pos != -1) {
                result.bsn = symbolicNameString.substring(0, pos);
                return result;
            }
            result.bsn = symbolicNameString;
            return result;
        } catch (IOException e) {
            if (this.debug) {
                e.printStackTrace();
                return null;
            }
            return null;
        }
    }

    private void buildOSGiBundleList() {
        StringBuffer finalBundleList = new StringBuffer(this.allBundles.size() * 30);
        for (BundleInfo searched : this.bundleList) {
            BundleInfo found = findBundle(searched.bsn, searched.version, true);
            finalBundleList.append("reference:").append(found.location).append(searched.startData).append(',');
        }
        if (!Boolean.FALSE.toString().equalsIgnoreCase(System.getProperties().getProperty(PROP_WEBSTART_AUTOMATIC_INSTALLATION))) {
            for (ArrayList toAdd : this.allBundles.values()) {
                Iterator iterator2 = toAdd.iterator();
                while (iterator2.hasNext()) {
                    BundleInfo bi = (BundleInfo) iterator2.next();
                    finalBundleList.append("reference:").append(bi.location).append(',');
                }
            }
        }
        System.getProperties().put(PROP_OSGI_BUNDLES, finalBundleList.toString());
    }
}
